@@ -15,12 +15,15 @@ def launchTerminal(request):
         return HttpResponseNotAllowed("shell must be setted as vapp params")
     #appid = "92895609"
     #appkey = "Bb0fqxdlKaU9Ct2fLwXtqNXGpKLVwlit"
-    appid = settings.THTERMCONF['appid']
-    appkey = settings.THTERMCONF['appkey']
+    print(settings.TH_WEBTERM_CONFIG)
+    appid = settings.TH_WEBTERM_CONFIG['WTERM_BACKEND_APPID']
+    appkey = settings.TH_WEBTERM_CONFIG['WTERM_BACKEND_APPKEY']
 
     cluster = request.session.get('cluster','')
-    server = settings.THTERMCONF['server']
+    server = settings.TH_WEBTERM_CONFIG['WTERM_BACKEND_HOST']
     user = request.session.get('systemUsername','')
+    if user in ["geou1","materials","geou5","materials","ligeng","geoeast","zhenggang2"]:
+        cluster = "TH-HPC2"
     client = THVClient(appid, appkey, server, cluster, user)
     token = client.launchApp(vapp)
 
